crt: tls: Rename __mingw_atexit_tls_callback_ptr to __mingw_cxa_tls_callback_ptr

It is a better description of the callback which is used for mingw cxa TLS API functionality.

Signed-off-by: LIU Hao <lh_mouse@126.com>
diff --git a/mingw-w64-crt/crt/tls_atexit_register.c b/mingw-w64-crt/crt/tls_atexit_register.c
index 316c69c..5432c17 100644
--- a/mingw-w64-crt/crt/tls_atexit_register.c
+++ b/mingw-w64-crt/crt/tls_atexit_register.c
@@ -11,10 +11,10 @@
 #include <sect_attribs.h>
 #include <internal.h>
 
-const int __mingw_atexit_tls_callback_caller_provider = 1;
-extern WINBOOL (WINAPI *const __mingw_atexit_tls_callback_ptr)(HANDLE,DWORD,LPVOID);
+const int __mingw_cxa_tls_callback_caller_provider = 1;
+extern WINBOOL (WINAPI *const __mingw_cxa_tls_callback_ptr)(HANDLE,DWORD,LPVOID);
 static void WINAPI callback(HANDLE handle, DWORD reason, LPVOID reserved) {
-  if (!__mingw_atexit_tls_callback_ptr(handle, reason, reserved))
+  if (!__mingw_cxa_tls_callback_ptr(handle, reason, reserved))
     _amsg_exit(16); /* _RT_THREAD - not enough space for thread data */
 }
 static _CRTALLOC(".CRT$XLB") const PIMAGE_TLS_CALLBACK callback_ptr = callback;
diff --git a/mingw-w64-crt/crt/crtdll.c b/mingw-w64-crt/crt/crtdll.c
index ecabf67..af7a477 100644
--- a/mingw-w64-crt/crt/crtdll.c
+++ b/mingw-w64-crt/crt/crtdll.c
@@ -32,8 +32,8 @@
 void (WINAPI *const __w64_mingwthr_callback_ptr)(HANDLE,DWORD,LPVOID) __attribute__((common)); /* tentative */
 const int __w64_mingwthr_callback_caller_provider = 1; /* crtdll.c calls __w64_mingwthr_callback_ptr */
 
-WINBOOL (WINAPI *const __mingw_atexit_tls_callback_ptr)(HANDLE,DWORD,LPVOID) __attribute__((common)); /* tentative */
-const int __mingw_atexit_tls_callback_caller_provider = 1; /* crtdll.c calls __mingw_atexit_tls_callback_ptr */
+WINBOOL (WINAPI *const __mingw_cxa_tls_callback_ptr)(HANDLE,DWORD,LPVOID) __attribute__((common)); /* tentative */
+const int __mingw_cxa_tls_callback_caller_provider = 1; /* crtdll.c calls __mingw_cxa_tls_callback_ptr */
 
 int (__cdecl *const __mingw_dll_atexit_table_func_ptr)(int) __attribute__((common)); /* tentative */
 
@@ -85,9 +85,9 @@
 	      if (ret != 0)
 		goto i__leave;
 	    }
-	  if (__mingw_atexit_tls_callback_ptr != NULL)
+	  if (__mingw_cxa_tls_callback_ptr != NULL)
 	    {
-	      if (! __mingw_atexit_tls_callback_ptr (hDllHandle, dwReason, lpreserved))
+	      if (! __mingw_cxa_tls_callback_ptr (hDllHandle, dwReason, lpreserved))
 		{
 		  ret = 1;
 		  goto i__leave;
@@ -108,8 +108,8 @@
 	}
       if (ret != 0)
 	{
-	  if (__mingw_atexit_tls_callback_ptr != NULL)
-	    __mingw_atexit_tls_callback_ptr (hDllHandle, DLL_PROCESS_DETACH, lpreserved);
+	  if (__mingw_cxa_tls_callback_ptr != NULL)
+	    __mingw_cxa_tls_callback_ptr (hDllHandle, DLL_PROCESS_DETACH, lpreserved);
 	  return FALSE;
 	}
       if (__dyn_tls_init_callback != NULL)
@@ -142,8 +142,8 @@
 	{
 	  if (__w64_mingwthr_callback_ptr != NULL)
 	    __w64_mingwthr_callback_ptr (hDllHandle, dwReason, lpreserved);
-	  if (__mingw_atexit_tls_callback_ptr != NULL)
-	    __mingw_atexit_tls_callback_ptr (hDllHandle, dwReason, lpreserved);
+	  if (__mingw_cxa_tls_callback_ptr != NULL)
+	    __mingw_cxa_tls_callback_ptr (hDllHandle, dwReason, lpreserved);
 	  if (__mingw_dll_atexit_table_func_ptr != NULL)
 	    __mingw_dll_atexit_table_func_ptr (1 /*execute*/);
 	  __mingw_dll_do_global_dtors ();
@@ -163,9 +163,9 @@
     {
       if (__w64_mingwthr_callback_ptr != NULL)
 	 __w64_mingwthr_callback_ptr (hDllHandle, dwReason, lpreserved);
-      if (__mingw_atexit_tls_callback_ptr != NULL)
+      if (__mingw_cxa_tls_callback_ptr != NULL)
 	{
-	  if (! __mingw_atexit_tls_callback_ptr (hDllHandle, dwReason, lpreserved))
+	  if (! __mingw_cxa_tls_callback_ptr (hDllHandle, dwReason, lpreserved))
 	    return FALSE;
 	}
     }
diff --git a/mingw-w64-crt/crt/tls_atexit.c b/mingw-w64-crt/crt/tls_atexit.c
index 0e4d57c..44dd5c8 100644
--- a/mingw-w64-crt/crt/tls_atexit.c
+++ b/mingw-w64-crt/crt/tls_atexit.c
@@ -169,8 +169,8 @@
   }
   return TRUE;
 }
-WINBOOL (WINAPI *const __mingw_atexit_tls_callback_ptr)(HANDLE,DWORD,LPVOID) = tls_callback;
+WINBOOL (WINAPI *const __mingw_cxa_tls_callback_ptr)(HANDLE,DWORD,LPVOID) = tls_callback;
 
-/* Force inclusion of code which calls __mingw_atexit_tls_callback */
-extern const int __mingw_atexit_tls_callback_caller_provider;
-static __attribute__((used)) const void *const _include_mingw_atexit_tls_callback_caller = &__mingw_atexit_tls_callback_caller_provider;
+/* Force inclusion of code which calls __mingw_cxa_tls_callback_ptr */
+extern const int __mingw_cxa_tls_callback_caller_provider;
+static __attribute__((used)) const void *const _include_mingw_cxa_tls_callback_caller = &__mingw_cxa_tls_callback_caller_provider;